/*
   Macro.   EolType.
   Author.  Carlo Hogeveen (carlo.hogeveen@xs4all.nl)
   Date.    5 July 1999.

   Purpose: Save unix files with EndOfLineType LF, save other files
            with EndOfLineType CR/LF, and load files with their
            existing EndOfLineType.

   Install: Copy EolType.s to TSE's "mac" directory.
            Compile EolType.s.
            Add "EolType" to TSE's Macro AutoLoad List.
            Execute the macro "EolType" once, to configure what filename
            prefixes indicate a unix filename, separated by a space.

   Example: x:\ j:\ u:\
*/
string prefixes [255] = ""
proc on_file_load()
   Set(EOLType, 0) // As loaded.
end
proc on_file_save()
   integer token_number = 0
   Set(EOLType, 3) // CR/LF.
   for token_number = 1 to NumTokens(prefixes, " ")
      if Lower(GetToken(prefixes, " ", token_number)) ==
         Lower(SubStr(CurrFilename(),
                      1,
                      Length(GetToken(prefixes, " ", token_number))))
         Set(EOLType, 2) // LF.
      endif
   endfor
end
proc WhenPurged()
   integer org_id = GetBufferId()
   EditFile(LoadDir() + "eoltype.dat", _DONT_PROMPT_)
   EmptyBuffer()
   InsertLine(prefixes)
   SaveAs(LoadDir() + "eoltype.dat", _OVERWRITE_|_DONT_PROMPT_)
   AbandonFile()
   GotoBufferId(org_id)
end
proc on_abandon_editor()
   WhenPurged()
   UnHook(on_file_load)
   UnHook(on_file_save)
   UnHook(on_abandon_editor)
end
proc WhenLoaded()
   integer org_id = GetBufferId()
   Hook(_ON_FILE_LOAD_, on_file_load)
   Hook(_ON_FILE_SAVE_, on_file_save)
   Hook(_ON_ABANDON_EDITOR_, on_abandon_editor)
   EditFile(LoadDir() + "eoltype.dat", _DONT_PROMPT_)
   BegFile()
   prefixes = GetText(1,CurrLineLen())
   AbandonFile()
   GotoBufferId(org_id)
end
proc Main()
   Ask("List possible prefixes of unix filenames, separated by a space:",
       prefixes)
end
